@@ -3,20 +3,20 @@
 #' @method summary PlackettLuce
 #' @export
 summary.PlackettLuce <- function(object,
-                                 ref = 1,
+                                 ref = 1L,
                                  ...) {
     coefs <- coef(object, ref = ref)
-    coefficients <- matrix(NA, nrow = length(coefs), ncol = 4,
+    coefficients <- matrix(NA, nrow = length(coefs), ncol = 4L,
                            dimnames = list(names(coefs),
                                            c("Estimate", "Std. Error",
                                              "z value", "Pr(>|z|)")))
-    coefficients[,1] <- coefs
-    se <- sqrt(diag(vcov(object, ref = ref)))
-    coefficients[names(se), 2] <- se
+    coefficients[,1L] <- coefs
+    se <- sqrt(diag(vcov(object, ref = ref, ...)))
+    coefficients[names(se), 2L] <- se
     ref <- attr(coefs, "ref")
-    if (length(ref) == 1) coefficients[attr(coefs, "ref"), 2] <- NA
-    coefficients[,3] <- coefficients[,1]/coefficients[,2]
-    coefficients[,4] <- 2 * pnorm(-abs(coefficients[, 3]))
+    if (length(ref) == 1L) coefficients[attr(coefs, "ref"), 2L] <- NA
+    coefficients[,3L] <- coefficients[,1L]/coefficients[,2L]
+    coefficients[,4L] <- 2L * pnorm(-abs(coefficients[, 3L]))
     structure(list(call = object$call,
                    deviance = deviance(object),
                    aic = AIC(object),
@@ -40,11 +40,13 @@ print.summary.PlackettLuce <-  function(x,
     printCoefmat(x$coefficients, digits = digits, na.print = "NA", ...)
 
     cat("\nResidual deviance:  ",
-        format(x$deviance, digits = max(5, digits + 1)), " on ",
-        format(x$df.residual, digits = max(5, digits + 1)),
+        format(x$deviance, digits = max(5L, digits + 1L)), " on ",
+        format(x$df.residual, digits = max(5L, digits + 1L)),
         " degrees of freedom", fill = TRUE, sep = "")
-    cat("AIC: ", format(x$aic, digits = max(4, digits + 1)), "\n")
+    cat("AIC: ", format(x$aic, digits = max(4L, digits + 1L)), "\n")
 
-    cat("Number of iterations: ",  x$iter, "\n", sep = "")
+    if (!is.null(x$call$gamma)){
+        cat("Number of outer iterations: ",  x$iter, "\n", sep = "")
+    } else  cat("Number of iterations: ",  x$iter, "\n", sep = "")
     invisible(x)
 }
